aboutsummaryrefslogtreecommitdiffstats
path: root/lib/public/TextToImage/IManager.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/TextToImage/IManager.php')
-rw-r--r--lib/public/TextToImage/IManager.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/public/TextToImage/IManager.php b/lib/public/TextToImage/IManager.php
index cfe38e3ce7f..bc16896b43b 100644
--- a/lib/public/TextToImage/IManager.php
+++ b/lib/public/TextToImage/IManager.php
@@ -28,6 +28,7 @@ namespace OCP\TextToImage;
use OCP\DB\Exception;
use OCP\PreConditionNotMetException;
+use OCP\TextToImage\Exception\TaskFailureException;
use OCP\TextToImage\Exception\TaskNotFoundException;
use RuntimeException;
@@ -51,7 +52,7 @@ interface IManager {
/**
* @param Task $task The task to run
* @throws PreConditionNotMetException If no or not the requested provider was registered but this method was still called
* @throws RuntimeException If something else failed
* @since 28.0.0
*/
public function runTask(Task $task): void;
@@ -71,7 +72,7 @@ interface IManager {
/**
* @throws Exception if there was a problem inserting the task into the database
* @throws PreConditionNotMetException if no provider is registered
* @throws RuntimeException If the task run fail
* @since 28.0.0
*/
public function runOrScheduleTask(Task $task) : void;
@@ -51,7 +52,7 @@ interface IManager {
* @param Task $task The task to run
* @throws PreConditionNotMetException If no or not the requested provider was registered but this method was still called
- * @throws RuntimeException If something else failed
+ * @throws TaskFailureException If something else failed
* @since 28.0.0
*/
@@ -71,7 +72,7 @@ interface IManager {
* @throws Exception if there was a problem inserting the task into the database
* @throws PreConditionNotMetException if no provider is registered
- * @throws RuntimeException If the task run fail
+ * @throws TaskFailureException If the task run failed
* @since 28.0.0
*/